@@ -92,7 +92,7 @@ public:
 	void begin()
 	{
 		kdDebug( 14010 ) << k_funcinfo << endl;
-		Kopete::WalletManager::self()->openWallet( this, TQT_SLOT( walletReceived( TDEWallet::Wallet* ) ) );
+		Kopete::WalletManager::self()->openWallet( this, TQ_SLOT( walletReceived( TDEWallet::Wallet* ) ) );
 	}
 
 	void walletReceived( TDEWallet::Wallet *wallet )
@@ -198,15 +198,15 @@ public:
 		mView->adjustSize();
 		passwdDialog->adjustSize();
 
-		connect( passwdDialog, TQT_SIGNAL( okClicked() ), TQT_SLOT( slotOkPressed() ) );
-		connect( passwdDialog, TQT_SIGNAL( cancelClicked() ), TQT_SLOT( slotCancelPressed() ) );
-		connect( this, TQT_SIGNAL( destroyed() ), passwdDialog, TQT_SLOT( deleteLater() ) );
+		connect( passwdDialog, TQ_SIGNAL( okClicked() ), TQ_SLOT( slotOkPressed() ) );
+		connect( passwdDialog, TQ_SIGNAL( cancelClicked() ), TQ_SLOT( slotCancelPressed() ) );
+		connect( this, TQ_SIGNAL( destroyed() ), passwdDialog, TQ_SLOT( deleteLater() ) );
 		passwdDialog->show();
 	}
 
 	void slotOkPressed()
 	{
-		TQString result = TQString::fromLocal8Bit( mView->m_password->password() );
+		TQString result = mView->m_password->password();
 		if ( mView->m_save_passwd->isChecked() )
 			mPassword.set( result );
 
@@ -455,14 +455,14 @@ void Kopete::Password::requestWithoutPrompt( TQObject *returnObj, const char *sl
 {
 	KopetePasswordRequest *request = new KopetePasswordGetRequestNoPrompt( returnObj, *this );
 	// call connect on returnObj so we can still connect if 'slot' is protected/private
-	returnObj->connect( request, TQT_SIGNAL( requestFinished( const TQString & ) ), slot );
+	returnObj->connect( request, TQ_SIGNAL( requestFinished( const TQString & ) ), slot );
 	request->begin();
 }
 
 void Kopete::Password::request( TQObject *returnObj, const char *slot, const TQPixmap &image, const TQString &prompt, Kopete::Password::PasswordSource source )
 {
 	KopetePasswordRequest *request = new KopetePasswordGetRequestPrompt( returnObj, *this, image, prompt, source );
-	returnObj->connect( request, TQT_SIGNAL( requestFinished( const TQString & ) ), slot );
+	returnObj->connect( request, TQ_SIGNAL( requestFinished( const TQString & ) ), slot );
 	request->begin();
 }
 
