@@ -31,7 +31,7 @@ class Contact;
  */
 class KOPETE_EXPORT KopeteContactAction : public TDEAction
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
