@@ -1180,14 +1180,14 @@ public:
 	SharedTimer( int period ) : period(period), users(0) {}
 	void attach( TQObject *target, const char *slot )
 	{
-		connect( this, TQT_SIGNAL(timeout()), target, slot );
+		connect( this, TQ_SIGNAL(timeout()), target, slot );
 		if( users++ == 0 )
 			start( period );
 		//kdDebug(14000) << "SharedTimer::attach: users is now " << users << "\n";
 	}
 	void detach( TQObject *target, const char *slot )
 	{
-		disconnect( this, TQT_SIGNAL(timeout()), target, slot );
+		disconnect( this, TQ_SIGNAL(timeout()), target, slot );
 		if( --users == 0 )
 			stop();
 		//kdDebug(14000) << "SharedTimer::detach: users is now " << users << "\n";
@@ -1227,9 +1227,9 @@ class Item::Private
 {
 public:
 	Private( Item *item )
-	 : layoutAnimateTimer( theLayoutAnimateTimer(), item, TQT_SLOT( slotLayoutAnimateItems() ) )
+	 : layoutAnimateTimer( theLayoutAnimateTimer(), item, TQ_SLOT( slotLayoutAnimateItems() ) )
 	 , animateLayout( true ), opacity( 1.0 )
-	 , visibilityTimer( theVisibilityTimer(), item, TQT_SLOT( slotUpdateVisibility() ) )
+	 , visibilityTimer( theVisibilityTimer(), item, TQ_SLOT( slotUpdateVisibility() ) )
 	 , visibilityLevel( 0 ), visibilityTarget( false ), searchMatch( true )
 	{
 	}
@@ -1305,10 +1305,10 @@ void Item::setEffects( bool animation, bool fading, bool folding )
 
 void Item::initLVI()
 {
-	connect( listView()->header(), TQT_SIGNAL( sizeChange( int, int, int ) ), TQT_SLOT( slotColumnResized() ) );
-	connect( &d->layoutTimer, TQT_SIGNAL( timeout() ), TQT_SLOT( slotLayoutItems() ) );
-	//connect( &d->layoutAnimateTimer, TQT_SIGNAL( timeout() ), TQT_SLOT( slotLayoutAnimateItems() ) );
-	//connect( &d->visibilityTimer, TQT_SIGNAL( timeout() ), TQT_SLOT( slotUpdateVisibility() ) );
+	connect( listView()->header(), TQ_SIGNAL( sizeChange( int, int, int ) ), TQ_SLOT( slotColumnResized() ) );
+	connect( &d->layoutTimer, TQ_SIGNAL( timeout() ), TQ_SLOT( slotLayoutItems() ) );
+	//connect( &d->layoutAnimateTimer, TQ_SIGNAL( timeout() ), TQ_SLOT( slotLayoutAnimateItems() ) );
+	//connect( &d->visibilityTimer, TQ_SIGNAL( timeout() ), TQ_SLOT( slotUpdateVisibility() ) );
 	setVisible( false );
 	setTargetVisibility( true );
 }
