@@ -20,7 +20,7 @@
 */
 class BookmarksPrefsSettings : public TQObject
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	enum UseSubfolders { Always=0, Never=1, SelectedContacts=2, UnselectedContacts=3 };
