@@ -121,7 +121,7 @@ KDialogBase( Plain, i18n("Select Public Key"), Details | Ok | Cancel, Ok, parent
                                             : "locationbar_erase"));
 	(void) new TQLabel(i18n("Search: "),hBar);
 	TDEListViewSearchLine* listViewSearch = new TDEListViewSearchLine(hBar);
-	connect(clearSearch, TQT_SIGNAL(pressed()), listViewSearch, TQT_SLOT(clear()));
+	connect(clearSearch, TQ_SIGNAL(pressed()), listViewSearch, TQ_SLOT(clear()));
 	
         keysList = new TDEListView( page );
 	 keysList->addColumn(i18n("Name"));
@@ -141,10 +141,10 @@ KDialogBase( Plain, i18n("Select Public Key"), Details | Ok | Cancel, Ok, parent
 	keysList->setColumnWidth(0,210);
 	keysList->setColumnWidth(1,210);
 
-        boutonboxoptions=new TQButtonGroup(5,Qt::Vertical ,page,0);
+        boutonboxoptions=new TQButtonGroup(5,TQt::Vertical ,page,0);
 	
 	TDEActionCollection *actcol=new TDEActionCollection(this);
-	(void) new TDEAction(i18n("&Go to Default Key"),goDefaultKey, TQT_TQOBJECT(this), TQT_SLOT(slotGotoDefaultKey()),actcol,"go_default_key");
+	(void) new TDEAction(i18n("&Go to Default Key"),goDefaultKey, this, TQ_SLOT(slotGotoDefaultKey()),actcol,"go_default_key");
 	
 	
         CBarmor=new TQCheckBox(i18n("ASCII armored encryption"),boutonboxoptions);
@@ -183,7 +183,7 @@ KDialogBase( Plain, i18n("Select Public Key"), Details | Ok | Cancel, Ok, parent
                 TQWhatsThis::add
                         (CBsymmetric,i18n("<b>Symmetrical encryption</b>: encryption does not use keys. You just need to give a password "
                                           "to encrypt/decrypt the file"));
-                TQObject::connect(CBsymmetric,TQT_SIGNAL(toggled(bool)),this,TQT_SLOT(isSymetric(bool)));
+                TQObject::connect(CBsymmetric,TQ_SIGNAL(toggled(bool)),this,TQ_SLOT(isSymetric(bool)));
 
 //BEGIN modified for Kopete
 
@@ -213,11 +213,11 @@ KDialogBase( Plain, i18n("Select Public Key"), Details | Ok | Cancel, Ok, parent
                 optiontxt->setText(customOptions);
                 TQWhatsThis::add
                         (optiontxt,i18n("<b>Custom option</b>: for experienced users only, allows you to enter a gpg command line option, like: '--armor'"));
-                TQObject::connect(optiontxt,TQT_SIGNAL(textChanged ( const TQString & )),this,TQT_SLOT(customOpts(const TQString & )));
+                TQObject::connect(optiontxt,TQ_SIGNAL(textChanged ( const TQString & )),this,TQ_SLOT(customOpts(const TQString & )));
         }*/
-        TQObject::connect(keysList,TQT_SIGNAL(doubleClicked(TQListViewItem *,const TQPoint &,int)),this,TQT_SLOT(slotOk()));
-//	TQObject::connect(this,TQT_SIGNAL(okClicked()),this,TQT_SLOT(crypte()));
-        TQObject::connect(CBuntrusted,TQT_SIGNAL(toggled(bool)),this,TQT_SLOT(refresh(bool)));
+        TQObject::connect(keysList,TQ_SIGNAL(doubleClicked(TQListViewItem *,const TQPoint &,int)),this,TQ_SLOT(slotOk()));
+//	TQObject::connect(this,TQ_SIGNAL(okClicked()),this,TQ_SLOT(crypte()));
+        TQObject::connect(CBuntrusted,TQ_SIGNAL(toggled(bool)),this,TQ_SLOT(refresh(bool)));
 
         char line[200]="\0";
         FILE *fp2;
@@ -350,8 +350,8 @@ void popupPublic::refreshkeys()
         KProcIO *encid=new KProcIO();
         *encid << "gpg"<<"--no-secmem-warning"<<"--no-tty"<<"--with-colon"<<"--list-keys";
         /////////  when process ends, update dialog infos
-        TQObject::connect(encid, TQT_SIGNAL(processExited(TDEProcess *)),this, TQT_SLOT(slotpreselect()));
-        TQObject::connect(encid, TQT_SIGNAL(readReady(KProcIO *)),this, TQT_SLOT(slotprocread(KProcIO *)));
+        TQObject::connect(encid, TQ_SIGNAL(processExited(TDEProcess *)),this, TQ_SLOT(slotpreselect()));
+        TQObject::connect(encid, TQ_SIGNAL(readReady(KProcIO *)),this, TQ_SLOT(slotprocread(KProcIO *)));
         encid->start(TDEProcess::NotifyOnExit,true);
 }
 
