@@ -21,7 +21,7 @@ This Task is the ancestor of Tasks that may need to create a folder on the serve
 */
 class NeedFolderTask : public ModifyContactListTask
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	NeedFolderTask(Task* parent);
