@@ -25,7 +25,7 @@
 
 class ShowTextDlg : public TQDialog
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
         ShowTextDlg(const TQString &fname, bool rich=FALSE, TQWidget *parent=0, const char *name=0);
