@@ -44,7 +44,7 @@ class dlgVCard;
  */
 class dlgJabberVCard : public KDialogBase
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
