@@ -20,7 +20,7 @@
 
 class SSITest : public TQApplication
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	SSITest(int argc, char ** argv);
