@@ -39,9 +39,9 @@ class OscarContact;
 class OscarAccountPrivate;
 class TQTextCodec;
 
-class KDE_EXPORT OscarAccount : public Kopete::PasswordedAccount
+class TDE_EXPORT OscarAccount : public Kopete::PasswordedAccount
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
@@ -200,6 +200,3 @@ private:
 };
 
 #endif
-
-//kate: tab-width 4; indent-mode csands;
-
