@@ -57,7 +57,7 @@ class TDEToggleAction;
  * \li get/set the ignore setting for the contact
  * \li get/set the visibility setting for the contact ( i.e. are we visible to the contact )
  */
-class KDE_EXPORT OscarContact : public Kopete::Contact
+class TDE_EXPORT OscarContact : public Kopete::Contact
 {
 TQ_OBJECT
   
