@@ -57,34 +57,34 @@ namespace KPF
 
     d->socket.setSocket(socket);
 
-    connect(&(d->socket), TQT_SIGNAL(readyRead()), this, TQT_SLOT(slotReadyRead()));
+    connect(&(d->socket), TQ_SIGNAL(readyRead()), this, TQ_SLOT(slotReadyRead()));
 
     connect
       (
        &(d->socket),
-       TQT_SIGNAL(bytesWritten(int)),
-       TQT_SLOT(slotBytesWritten(int))
+       TQ_SIGNAL(bytesWritten(int)),
+       TQ_SLOT(slotBytesWritten(int))
       );
 
     connect
       (
        &(d->socket),
-       TQT_SIGNAL(connectionClosed()),
-       TQT_SLOT(slotConnectionClosed())
+       TQ_SIGNAL(connectionClosed()),
+       TQ_SLOT(slotConnectionClosed())
       );
 
     connect
       (
        &(d->idleTimer),
-       TQT_SIGNAL(timeout()),
-       TQT_SLOT(slotTimeout())
+       TQ_SIGNAL(timeout()),
+       TQ_SLOT(slotTimeout())
       );
 
     connect
       (
        &(d->readTimer),
-       TQT_SIGNAL(timeout()),
-       TQT_SLOT(slotRead())
+       TQ_SIGNAL(timeout()),
+       TQ_SLOT(slotRead())
       );
 
     // If nothing happens for a bit, cancel ourselves.
@@ -207,7 +207,7 @@ namespace KPF
 
     TQStringList l(TQStringList::split(' ', line));
 
-    // A request usually looks like TQT_METHOD PATH PROTOCOL but we don't
+    // A request usually looks like METHOD PATH PROTOCOL but we don't
     // require PROTOCOL - we just assume HTTP/0.9 and act accordingly.
 
     if (l.count() == 2)
@@ -238,7 +238,7 @@ namespace KPF
     bool
   Server::checkRequest()
   {
-    // We only handle TQT_METHOD of GET or HEAD.
+    // We only handle METHOD of GET or HEAD.
 
     if (Request::Unsupported == d->request.method())
     {
