@@ -196,7 +196,7 @@ MonthlyWidget::MonthlyWidget(TQWidget *parent) :
   lv->setMinimumHeight(280);
   lv->setSelectionMode(TQListView::Extended);
   selectionItem = 0L;
-  connect(lv, TQT_SIGNAL(selectionChanged()), TQT_SLOT(slotSelectionChanged()));
+  connect(lv, TQ_SIGNAL(selectionChanged()), TQ_SLOT(slotSelectionChanged()));
 
   lv2 = new TDEListView(this);
   lv2->addColumn(i18n("Connection"));
@@ -225,10 +225,10 @@ MonthlyWidget::MonthlyWidget(TQWidget *parent) :
   cboConnections = new TQComboBox(false, this);            // add a combo box to select connections
   cboConnections->setMaximumWidth(200);                   // a resonable size
   cboConnections->insertItem(i18n("All Connections"));    // default to all connections
-  connect(cboConnections, TQT_SIGNAL(activated(int)),
-	  this, TQT_SLOT(slotConnections(int)));
+  connect(cboConnections, TQ_SIGNAL(activated(int)),
+	  this, TQ_SLOT(slotConnections(int)));
 
-  bbox = new KButtonBox(this, Qt::Vertical);
+  bbox = new KButtonBox(this, TQt::Vertical);
   prev = bbox->addButton(i18n("&Prev Month"));
   next = bbox->addButton(i18n("&Next Month"));
   bbox->addStretch(1);
@@ -236,14 +236,14 @@ MonthlyWidget::MonthlyWidget(TQWidget *parent) :
   bbox->addStretch(1);
   exportBttn = bbox->addButton(i18n("&Export..."));
 
-  connect(prev, TQT_SIGNAL(released()),
-	  this, TQT_SLOT(prevMonth()));
-  connect(next, TQT_SIGNAL(released()),
-	  this, TQT_SLOT(nextMonth()));
-  connect(today, TQT_SIGNAL(released()),
-	  this, TQT_SLOT(currentMonth()));
-  connect(exportBttn, TQT_SIGNAL(clicked()),
-	  this, TQT_SLOT(exportWizard()));
+  connect(prev, TQ_SIGNAL(released()),
+	  this, TQ_SLOT(prevMonth()));
+  connect(next, TQ_SIGNAL(released()),
+	  this, TQ_SLOT(nextMonth()));
+  connect(today, TQ_SIGNAL(released()),
+	  this, TQ_SLOT(currentMonth()));
+  connect(exportBttn, TQ_SIGNAL(clicked()),
+	  this, TQ_SLOT(exportWizard()));
 
   bbox->addStretch(8);
   bbox->layout();
