@@ -933,10 +933,6 @@ void RFBController::sendSessionEstablished()
         emit sessionEstablished(remoteIp);
 }
 
-#ifdef __osf__
-extern "C" Bool XShmQueryExtension(Display*);
-#endif
-
 bool RFBController::checkX11Capabilities() {
 	int bp1, bp2, majorv, minorv;
 	Bool r = XTestQueryExtension(tqt_xdisplay(), &bp1, &bp2,
