@@ -110,21 +110,21 @@ open_ksirc::open_ksirc
   TQString blah = i18n("Recent");
   setGroup(blah);
 
-  connect(ComboB_ServerGroup, TQT_SIGNAL(activated( const TQString& )),
-          this, TQT_SLOT(setGroup( const TQString& )));
-  connect(ComboB_ServerName,  TQT_SIGNAL(activated( const TQString& )),
-          this, TQT_SLOT(setServer( const TQString& )));
+  connect(ComboB_ServerGroup, TQ_SIGNAL(activated( const TQString& )),
+          this, TQ_SLOT(setGroup( const TQString& )));
+  connect(ComboB_ServerName,  TQ_SIGNAL(activated( const TQString& )),
+          this, TQ_SLOT(setServer( const TQString& )));
 
-  connect(PB_Connect, TQT_SIGNAL(clicked()), this, TQT_SLOT(clickConnect()));
-  connect(PB_Edit, TQT_SIGNAL(clicked()), this, TQT_SLOT(clickEdit()));
-  connect(PB_Cancel, TQT_SIGNAL(clicked()), this, TQT_SLOT(clickCancel()));
+  connect(PB_Connect, TQ_SIGNAL(clicked()), this, TQ_SLOT(clickConnect()));
+  connect(PB_Edit, TQ_SIGNAL(clicked()), this, TQ_SLOT(clickEdit()));
+  connect(PB_Cancel, TQ_SIGNAL(clicked()), this, TQ_SLOT(clickCancel()));
 
   PB_Connect->setDefault(TRUE);
   PB_Connect->setAutoDefault(TRUE);
   PB_Edit->setEnabled(false); // Not yet implemented.
 
   ComboB_ServerName->setFocus();
-  connect(ComboB_ServerName, TQT_SIGNAL(enterPressed()), this, TQT_SLOT(clickConnect()));
+  connect(ComboB_ServerName, TQ_SIGNAL(enterPressed()), this, TQ_SLOT(clickConnect()));
 }
 
 // insert a sorted list of groups into ComboB_ServerGroup, note that
