@@ -17,7 +17,7 @@ class KKeyChooser;
 
 class PageShortcuts : public PageShortcutsBase
 {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
