@@ -66,7 +66,7 @@ public:
     }
 };
 
-extern "C" KDE_EXPORT int kdemain( int argc, char ** argv )
+extern "C" TDE_EXPORT int kdemain( int argc, char ** argv )
 {
     TDEAboutData aboutData( "ksirc", I18N_NOOP("KSirc"),
         KSIRC_VERSION, description, TDEAboutData::License_Artistic,
