@@ -19,7 +19,7 @@
 
 void KSTabWidget::mousePressEvent(TQMouseEvent *e)
 {
-    if(e->button() == Qt::RightButton){
+    if(e->button() == TQt::RightButton){
         TQPoint p = tabBar()->mapFromParent(e->pos());
 	TQTab *tab = tabBar()->selectTab(p);
 	if(tab){
@@ -39,11 +39,11 @@ MDITopLevel::MDITopLevel(TQWidget *parent, const char *name)
 
     setCentralWidget( m_tab );
 
-    connect( m_tab, TQT_SIGNAL( currentChanged( TQWidget * ) ),
-             this, TQT_SLOT( slotCurrentChanged( TQWidget * ) ) );
+    connect( m_tab, TQ_SIGNAL( currentChanged( TQWidget * ) ),
+             this, TQ_SLOT( slotCurrentChanged( TQWidget * ) ) );
 
-    connect( m_tab, TQT_SIGNAL( showContexMenu(TQWidget *, const TQPoint &) ),
-             this, TQT_SLOT( slotShowContexMenu(TQWidget *, const TQPoint &) ) );
+    connect( m_tab, TQ_SIGNAL( showContexMenu(TQWidget *, const TQPoint &) ),
+             this, TQ_SLOT( slotShowContexMenu(TQWidget *, const TQPoint &) ) );
 
     TDEConfig *config = kapp->config();
     config->setGroup("MDI");
@@ -54,7 +54,7 @@ MDITopLevel::MDITopLevel(TQWidget *parent, const char *name)
     m_addressedIcon = UserIcon( "application-vnd.tde.info" );
 
     m_pop = new TDEPopupMenu(m_tab, "");
-    m_pop->insertItem( SmallIcon("window-close"), i18n("Close"), this, TQT_SLOT( slotCloseLastWid() ));
+    m_pop->insertItem( SmallIcon("window-close"), i18n("Close"), this, TQ_SLOT( slotCloseLastWid() ));
 
 }
 
@@ -89,16 +89,16 @@ void MDITopLevel::addWidget( TQWidget *widget, bool show )
 
     m_tabWidgets.append( widget );
 
-    connect( widget, TQT_SIGNAL( destroyed() ) ,
-             this, TQT_SLOT( slotWidgetDestroyed() ) );
+    connect( widget, TQ_SIGNAL( destroyed() ) ,
+             this, TQ_SLOT( slotWidgetDestroyed() ) );
 
-    connect( widget, TQT_SIGNAL( changeChannel( const TQString &, const TQString & ) ),
-             this, TQT_SLOT( slotChangeChannelName( const TQString &, const TQString & ) ) );
+    connect( widget, TQ_SIGNAL( changeChannel( const TQString &, const TQString & ) ),
+             this, TQ_SLOT( slotChangeChannelName( const TQString &, const TQString & ) ) );
 
     widget->installEventFilter( this );
 
-    connect( widget, TQT_SIGNAL( changed( bool, TQString ) ),
-             this, TQT_SLOT( slotMarkPageDirty( bool ) ) );
+    connect( widget, TQ_SIGNAL( changed( bool, TQString ) ),
+             this, TQ_SLOT( slotMarkPageDirty( bool ) ) );
 }
 
 void MDITopLevel::removeWidget( TQWidget *widget )
@@ -207,7 +207,7 @@ void MDITopLevel::slotMarkPageDirty( bool addressed )
 {
     // This is called when a line appeared in this channel.
     // addressed is true if it was addressed to the user
-    TDEMainWindow *window = dynamic_cast<TDEMainWindow *>( TQT_TQWIDGET(const_cast<TQT_BASE_OBJECT_NAME *>( sender() )) );
+    TDEMainWindow *window = dynamic_cast<TDEMainWindow *>( const_cast<TQObject*>( sender() ) );
 
     if ( !window )
         return;
@@ -225,7 +225,7 @@ void MDITopLevel::slotMarkPageDirty( bool addressed )
 
 void MDITopLevel::slotChangeChannelName( const TQString &, const TQString &channelName )
 {
-    TDEMainWindow *window = dynamic_cast<TDEMainWindow *>( TQT_TQWIDGET(const_cast<TQT_BASE_OBJECT_NAME *>( sender() )) );
+    TDEMainWindow *window = dynamic_cast<TDEMainWindow *>( const_cast<TQObject*>( sender() ) );
 
     if ( !window )
         return;
