@@ -121,7 +121,7 @@ KSircTopLevel::KSircTopLevel(KSircProcess *_proc, const KSircChannel &channelInf
 
   m_topic = TQString();
 
-  TQCString kstl_name = TQCString(TQT_TQOBJECT(this)->name()) + "_" + "toplevel";
+  TQCString kstl_name = TQCString(this->name()) + "_" + "toplevel";
   setName(kstl_name);
 
   if(!m_channelInfo.channel().isEmpty()) {
@@ -149,34 +149,34 @@ KSircTopLevel::KSircTopLevel(KSircProcess *_proc, const KSircChannel &channelInf
   m_channelInfo.setEncoding(ksopts->chan(m_channelInfo).encoding);
 
   selector = new charSelector();
-  connect(selector, TQT_SIGNAL(clicked()), this, TQT_SLOT(insertText()));
+  connect(selector, TQ_SIGNAL(clicked()), this, TQ_SLOT(insertText()));
   selector->setFont(ksopts->defaultFont.family());
 
-  file = new TQPopupMenu(this, TQCString(TQT_TQOBJECT(this)->name()) + "_popup_file");
+  file = new TQPopupMenu(this, TQCString(this->name()) + "_popup_file");
   file->setCheckable(true);
 
-  TDEAction *act = KStdAction::openNew( TQT_TQOBJECT(this), TQT_SLOT( newWindow() ), actionCollection() );
+  TDEAction *act = KStdAction::openNew( this, TQ_SLOT( newWindow() ), actionCollection() );
   act->plug( file );
-  file->insertItem(i18n("New Ser&ver..."), servercontroller::self(), TQT_SLOT(new_connection()), Key_F2);
+  file->insertItem(i18n("New Ser&ver..."), servercontroller::self(), TQ_SLOT(new_connection()), Key_F2);
   file->insertSeparator();
-  file->insertItem(i18n("&DCC Manager..."), this, TQT_SLOT(showDCCMgr()));
-  file->insertItem(i18n("&Save to Logfile..."), this, TQT_SLOT(saveCurrLog()), CTRL + Key_S);
+  file->insertItem(i18n("&DCC Manager..."), this, TQ_SLOT(showDCCMgr()));
+  file->insertItem(i18n("&Save to Logfile..."), this, TQ_SLOT(saveCurrLog()), CTRL + Key_S);
 
-  tsitem = file->insertItem(i18n("Time St&amp"), this, TQT_SLOT(toggleTimestamp()), CTRL + Key_T);
+  tsitem = file->insertItem(i18n("Time St&amp"), this, TQ_SLOT(toggleTimestamp()), CTRL + Key_T);
   file->setItemChecked(tsitem, ksopts->chan(m_channelInfo).timeStamp);
 
-  fjpitem = file->insertItem(i18n("Hide Join/Part Messages"), this, TQT_SLOT(toggleFilterJoinPart()));
+  fjpitem = file->insertItem(i18n("Hide Join/Part Messages"), this, TQ_SLOT(toggleFilterJoinPart()));
   file->setItemChecked(fjpitem, ksopts->chan(m_channelInfo).filterJoinPart);
 
-  file->insertItem(i18n("Character &Table"), selector, TQT_SLOT(show()), CTRL + Key_H);
-  beepitem = file->insertItem(i18n("N&otify on Change"), this, TQT_SLOT(toggleBeep()), CTRL + Key_P);
+  file->insertItem(i18n("Character &Table"), selector, TQ_SLOT(show()), CTRL + Key_H);
+  beepitem = file->insertItem(i18n("N&otify on Change"), this, TQ_SLOT(toggleBeep()), CTRL + Key_P);
   file->setItemChecked(beepitem, ksopts->chan(m_channelInfo).beepOnMsg);
 
-  encodingAction = new TDESelectAction( i18n( "&Encoding" ), 0, TQT_TQOBJECT(this) );
-  connect( encodingAction, TQT_SIGNAL( activated() ), this, TQT_SLOT( setEncoding() ) );
+  encodingAction = new TDESelectAction( i18n( "&Encoding" ), 0, this );
+  connect( encodingAction, TQ_SIGNAL( activated() ), this, TQ_SLOT( setEncoding() ) );
   TQStringList encodings = TDEGlobal::charsets()->descriptiveEncodingNames();
 
-  topicitem = file->insertItem(i18n("S&how Topic"), this, TQT_SLOT(toggleTopic()), CTRL + Key_O);
+  topicitem = file->insertItem(i18n("S&how Topic"), this, TQ_SLOT(toggleTopic()), CTRL + Key_O);
   if (isPrivateChat() || m_channelInfo.channel().startsWith("!no_channel")) {
       file->setItemEnabled(topicitem, false);
   }
@@ -184,7 +184,7 @@ KSircTopLevel::KSircTopLevel(KSircProcess *_proc, const KSircChannel &channelInf
       file->setItemChecked(topicitem, ksopts->chan(m_channelInfo).topicShow);
   }
 
-  tickeritem = file->insertItem(i18n("Ticker &Mode"), this, TQT_SLOT(toggleTicker()));
+  tickeritem = file->insertItem(i18n("Ticker &Mode"), this, TQ_SLOT(toggleTicker()));
 
   // remove utf16/ucs2 as it just doesn't work for IRC
   TQStringList::Iterator encodingIt = encodings.begin();
@@ -208,7 +208,7 @@ KSircTopLevel::KSircTopLevel(KSircProcess *_proc, const KSircChannel &channelInf
   setEncoding();
 
   file->insertSeparator();
-  act = KStdAction::close( TQT_TQOBJECT(this), TQT_SLOT( terminate() ), actionCollection() );
+  act = KStdAction::close( this, TQ_SLOT( terminate() ), actionCollection() );
   act->plug( file );
 
   kmenu = menuBar();
@@ -231,12 +231,12 @@ KSircTopLevel::KSircTopLevel(KSircProcess *_proc, const KSircChannel &channelInf
 
   ksTopic = new KSircTopic( top );
   ksTopic->setFont(ksopts->defaultFont);
-  connect( ksTopic, TQT_SIGNAL( topicChange( const TQString & ) ),
-           this, TQT_SLOT( setTopicIntern( const TQString & ) ) );
+  connect( ksTopic, TQ_SIGNAL( topicChange( const TQString & ) ),
+           this, TQ_SLOT( setTopicIntern( const TQString & ) ) );
 
-  TQCString kstn = TQCString(TQT_TQOBJECT(this)->name()) + "_";
+  TQCString kstn = TQCString(this->name()) + "_";
 
-  pan = new TQSplitter(Qt::Horizontal, top, kstn + "splitter");
+  pan = new TQSplitter(TQt::Horizontal, top, kstn + "splitter");
 #if KDE_IS_VERSION(3,1,92)
   pan->setOpaqueResize( TDEGlobalSettings::opaqueResize() );
 #else
@@ -249,8 +249,8 @@ KSircTopLevel::KSircTopLevel(KSircProcess *_proc, const KSircChannel &channelInf
   nicks_box = new TQVBox(pan);
 
   channelButtons = new chanButtons(ksircProcess(), nicks_box);
-  connect(channelButtons, TQT_SIGNAL(mode(TQString, int, TQString)),
-           this, TQT_SLOT(setMode(TQString, int, TQString)));
+  connect(channelButtons, TQ_SIGNAL(mode(TQString, int, TQString)),
+           this, TQ_SLOT(setMode(TQString, int, TQString)));
 
   nicks = new aListBox(nicks_box, kstn + "aListBox");
   nicks->setFocusPolicy(TQWidget::NoFocus);
@@ -312,11 +312,11 @@ KSircTopLevel::KSircTopLevel(KSircProcess *_proc, const KSircChannel &channelInf
   mainw->enableTimeStamps(ksopts->chan(m_channelInfo).timeStamp);
 
   edit = new TQPopupMenu(this);
-  act = KStdAction::copy( TQT_TQOBJECT(mainw), TQT_SLOT( copy() ), actionCollection() );
+  act = KStdAction::copy( mainw, TQ_SLOT( copy() ), actionCollection() );
   act->plug( edit );
-  act = KStdAction::paste( TQT_TQOBJECT(this), TQT_SLOT( pasteToWindow() ), actionCollection() );
+  act = KStdAction::paste( this, TQ_SLOT( pasteToWindow() ), actionCollection() );
   act->plug( edit );
-  edit->insertItem(i18n("C&lear Window"), this, TQT_SLOT(clearWindow()), CTRL + Key_L);
+  edit->insertItem(i18n("C&lear Window"), this, TQ_SLOT(clearWindow()), CTRL + Key_L);
   kmenu->insertItem(i18n("&Edit"), edit, -1, -1);
 
   linee = new aHistLineEdit(top, "");
@@ -353,8 +353,8 @@ KSircTopLevel::KSircTopLevel(KSircProcess *_proc, const KSircChannel &channelInf
   }
 
 
-  connect(mainw, TQT_SIGNAL(pasteReq( const TQString& )),
-          this, TQT_SLOT( slotTextDropped( const TQString& )));
+  connect(mainw, TQ_SIGNAL(pasteReq( const TQString& )),
+          this, TQ_SLOT( slotTextDropped( const TQString& )));
 
   nicks->setFont(ksopts->defaultFont);
 
@@ -370,17 +370,17 @@ KSircTopLevel::KSircTopLevel(KSircProcess *_proc, const KSircChannel &channelInf
       linee->setWordWrap(TQTextEdit::WidgetWidth);
   }
 
-  connect(linee, TQT_SIGNAL(gotFocus()),
-          this, TQT_SLOT(gotFocus()));
-  connect(linee, TQT_SIGNAL(lostFocus()),
-          this, TQT_SLOT(lostFocus()));
-  connect(linee, TQT_SIGNAL(pasteText(const TQString&)),
-          this, TQT_SLOT(slotTextDropped(const TQString&)));
-  connect(linee, TQT_SIGNAL(notTab()),
-          this, TQT_SLOT(lineeNotTab()));
+  connect(linee, TQ_SIGNAL(gotFocus()),
+          this, TQ_SLOT(gotFocus()));
+  connect(linee, TQ_SIGNAL(lostFocus()),
+          this, TQ_SLOT(lostFocus()));
+  connect(linee, TQ_SIGNAL(pasteText(const TQString&)),
+          this, TQ_SLOT(slotTextDropped(const TQString&)));
+  connect(linee, TQ_SIGNAL(notTab()),
+          this, TQ_SLOT(lineeNotTab()));
 
-  connect( linee, TQT_SIGNAL( gotReturnPressed() ),
-           this, TQT_SLOT( returnPressed() ) );
+  connect( linee, TQ_SIGNAL( gotReturnPressed() ),
+           this, TQ_SLOT( returnPressed() ) );
 
   linee->setFocus();  // Give SLE focus
   linee->slotMaybeResize();
@@ -440,7 +440,7 @@ KSircTopLevel::KSircTopLevel(KSircProcess *_proc, const KSircChannel &channelInf
           cml.insert(top, new TQPopupMenu(this));
           command->insertItem(top, cml[top]);
       }
-      cml[top]->insertItem(item, this, TQT_SLOT(cmd_process(int)), 0, i);
+      cml[top]->insertItem(item, this, TQ_SLOT(cmd_process(int)), 0, i);
 
       i++;
   }
@@ -449,17 +449,17 @@ KSircTopLevel::KSircTopLevel(KSircProcess *_proc, const KSircChannel &channelInf
 
   kmenu->insertItem( KStdGuiItem::help().text(), helpMenu( TQString(), false ));
 
-  connect(user_controls, TQT_SIGNAL(activated(int)),
-          this, TQT_SLOT(UserParseMenu(int)));
+  connect(user_controls, TQ_SIGNAL(activated(int)),
+          this, TQ_SLOT(UserParseMenu(int)));
 
-  connect(nicks, TQT_SIGNAL(contextMenuRequested(int)), this,
-          TQT_SLOT(UserSelected(int)));
-  connect(nicks, TQT_SIGNAL(selectedNick(const TQString &)),
-          this, TQT_SLOT(openQueryFromNick(const TQString &)));
-  connect(nicks, TQT_SIGNAL(mouseButtonClicked ( int, TQListBoxItem *, const TQPoint &)),
-          this, TQT_SLOT(pasteToNickList(int, TQListBoxItem *, const TQPoint &)));
-  connect(nicks, TQT_SIGNAL(textDropped( const TQListBoxItem *, const TQString& )),
-          this, TQT_SLOT(dndTextToNickList(const TQListBoxItem *, const TQString&)));
+  connect(nicks, TQ_SIGNAL(contextMenuRequested(int)), this,
+          TQ_SLOT(UserSelected(int)));
+  connect(nicks, TQ_SIGNAL(selectedNick(const TQString &)),
+          this, TQ_SLOT(openQueryFromNick(const TQString &)));
+  connect(nicks, TQ_SIGNAL(mouseButtonClicked ( int, TQListBoxItem *, const TQPoint &)),
+          this, TQ_SLOT(pasteToNickList(int, TQListBoxItem *, const TQPoint &)));
+  connect(nicks, TQ_SIGNAL(textDropped( const TQListBoxItem *, const TQString& )),
+          this, TQ_SLOT(dndTextToNickList(const TQListBoxItem *, const TQString&)));
 
   UserUpdateMenu();  // Must call to update Popup.
 
@@ -467,10 +467,10 @@ KSircTopLevel::KSircTopLevel(KSircProcess *_proc, const KSircChannel &channelInf
 
   accel->connectItem(accel->insertItem(SHIFT + Key_PageUp),
                      this,
-                     TQT_SLOT(AccelScrollUpPage()));
+                     TQ_SLOT(AccelScrollUpPage()));
   accel->connectItem(accel->insertItem(SHIFT + Key_PageDown),
                      this,
-                     TQT_SLOT(AccelScrollDownPage()));
+                     TQ_SLOT(AccelScrollDownPage()));
 
   /*
    * Pageup/dn
@@ -479,41 +479,41 @@ KSircTopLevel::KSircTopLevel(KSircProcess *_proc, const KSircChannel &channelInf
 
   accel->connectItem(accel->insertItem(Key_PageUp),
                      this,
-                     TQT_SLOT(AccelScrollUpPage()));
+                     TQ_SLOT(AccelScrollUpPage()));
   accel->connectItem(accel->insertItem(Key_PageDown),
                      this,
-                     TQT_SLOT(AccelScrollDownPage()));
+                     TQ_SLOT(AccelScrollDownPage()));
 
   /*
    * These are not presently implemented, so let's not fill the logs.
   accel->connectItem(accel->insertItem(CTRL + Key_Return),
                      this,
-                     TQT_SLOT(AccelPriorMsgNick()));
+                     TQ_SLOT(AccelPriorMsgNick()));
 
   accel->connectItem(accel->insertItem(CTRL + SHIFT + Key_Return),
                      this,
-                     TQT_SLOT(AccelNextMsgNick()));
+                     TQ_SLOT(AccelNextMsgNick()));
   */
 
   accel->connectItem(accel->insertItem(Key_Tab), // adds TAB accelerator
                      this,                         // connected to the main
-                     TQT_SLOT(TabNickCompletionNormal()));  // TabNickCompletion() slot
+                     TQ_SLOT(TabNickCompletionNormal()));  // TabNickCompletion() slot
   accel->connectItem(accel->insertItem(SHIFT+Key_Tab), // adds TAB accelerator
                      this,                         // connected to the main
-                     TQT_SLOT(TabNickCompletionShift()));  // TabNickCompletion() slot
+                     TQ_SLOT(TabNickCompletionShift()));  // TabNickCompletion() slot
   accel->connectItem(accel->insertItem(CTRL + Key_N),
-                     this, TQT_SLOT(newWindow()));
+                     this, TQ_SLOT(newWindow()));
 //  accel->connectItem(accel->insertItem(CTRL + Key_S),
-//                     this, TQT_SLOT(toggleTimestamp()));
+//                     this, TQ_SLOT(toggleTimestamp()));
 
   // Drag & Drop
-  connect( mainw, TQT_SIGNAL( textDropped(const TQString&) ),
-           TQT_SLOT( slotTextDropped(const TQString&) ));
-  connect( mainw, TQT_SIGNAL( urlsDropped(const TQStringList&) ),
-           TQT_SLOT( slotDropURLs(const TQStringList&) ));
-  connect( nicks, TQT_SIGNAL( urlsDropped( const TQStringList&, const TQString& )),
-           TQT_SLOT( slotDccURLs( const TQStringList&, const TQString& )));
-  connect( this, TQT_SIGNAL( changed(bool, TQString) ), this, TQT_SLOT( doChange(bool, TQString) ));
+  connect( mainw, TQ_SIGNAL( textDropped(const TQString&) ),
+           TQ_SLOT( slotTextDropped(const TQString&) ));
+  connect( mainw, TQ_SIGNAL( urlsDropped(const TQStringList&) ),
+           TQ_SLOT( slotDropURLs(const TQStringList&) ));
+  connect( nicks, TQ_SIGNAL( urlsDropped( const TQStringList&, const TQString& )),
+           TQ_SLOT( slotDccURLs( const TQStringList&, const TQString& )));
+  connect( this, TQ_SIGNAL( changed(bool, TQString) ), this, TQ_SLOT( doChange(bool, TQString) ));
 
   mainw->setAcceptFiles( isPrivateChat() );
   resize(600, 360);
@@ -748,8 +748,8 @@ void KSircTopLevel::TabNickCompletion(int dir)
       TQString line = tab_nick + ": "; // tab_nick holds the last night since we haven't overritten it yet.
       linee->setText(line);
       linee->setCursorPosition(line.length());
-      connect(linee, TQT_SIGNAL(notTab()),
-	      this, TQT_SLOT(lineeNotTab()));
+      connect(linee, TQ_SIGNAL(notTab()),
+	      this, TQ_SLOT(lineeNotTab()));
       return;
   }
 
@@ -800,8 +800,8 @@ void KSircTopLevel::TabNickCompletion(int dir)
 
   tab_pressed = tab; // setText causes lineeTextChanged to get called and erase tab_pressed
 
-  connect(linee, TQT_SIGNAL(notTab()),
-          this, TQT_SLOT(lineeNotTab()));
+  connect(linee, TQ_SIGNAL(notTab()),
+          this, TQ_SLOT(lineeNotTab()));
 
 }
 
@@ -1193,7 +1193,7 @@ void KSircTopLevel::AccelScrollUpPage()
 void KSircTopLevel::newWindow()
 {
   NewWindowDialog w(KSircChannel(m_channelInfo.server(), TQString()));
-  connect(&w, TQT_SIGNAL(openTopLevel(const KSircChannel &)), TQT_SIGNAL(open_toplevel(const KSircChannel &)));
+  connect(&w, TQ_SIGNAL(openTopLevel(const KSircChannel &)), TQ_SIGNAL(open_toplevel(const KSircChannel &)));
   w.exec();
 }
 
@@ -1285,9 +1285,9 @@ void KSircTopLevel::control_message(int command, TQString str)
           logFile->open();
       }
       setName(m_channelInfo.server().utf8() + "_" + m_channelInfo.channel().utf8() + "_" + "toplevel");
-      pan->setName(TQCString(TQT_TQOBJECT(this)->name()) + "_" + "TQSplitter");
-      kmenu->setName(TQCString(TQT_TQOBJECT(this)->name()) + "_tdetoolframe");
-      linee->setName(TQCString(TQT_TQOBJECT(this)->name()) + "_" + "LineEnter");
+      pan->setName(TQCString(this->name()) + "_" + "TQSplitter");
+      kmenu->setName(TQCString(this->name()) + "_tdetoolframe");
+      linee->setName(TQCString(this->name()) + "_" + "LineEnter");
       kmenu->show();
       setCaption(m_channelInfo.channel());
       emit currentWindow(this);
@@ -1505,7 +1505,7 @@ void KSircTopLevel::pasteToNickList(int button,
 				    TQListBoxItem *item,
 				    const TQPoint &)
 {
-    if(button == Qt::MidButton && item){
+    if(button == TQt::MidButton && item){
 	KSircChannel ci(m_channelInfo.server(), item->text().lower());
 	emit open_toplevel(ci);
 
@@ -1637,8 +1637,8 @@ void KSircTopLevel::clearWindow()
 void KSircTopLevel::lineeNotTab()
 {
   tab_pressed = -1;
-  disconnect(linee, TQT_SIGNAL(notTab()),
-	     this, TQT_SLOT(lineeNotTab()));
+  disconnect(linee, TQ_SIGNAL(notTab()),
+	     this, TQ_SLOT(lineeNotTab()));
   addCompleteNick(tab_nick);
 }
 
@@ -1651,7 +1651,7 @@ bool KSircTopLevel::event( TQEvent *e)
     if(e->type() == TQEvent::ApplicationPaletteChange ||
        e->type() == TQEvent::ApplicationFontChange)
     {
-	TQTimer::singleShot(750, this, TQT_SLOT(initColors()));
+	TQTimer::singleShot(750, this, TQ_SLOT(initColors()));
 	initColors();
     }
     return TDEMainWindow::event(e);
@@ -1804,7 +1804,7 @@ void KSircTopLevel::toggleTicker()
         ticker->show();
         displayMgr->hide(this);
 
-        connect(ticker, TQT_SIGNAL(doubleClick()), this, TQT_SLOT(toggleTicker()));
+        connect(ticker, TQ_SIGNAL(doubleClick()), this, TQ_SLOT(toggleTicker()));
     }
 }
 
