@@ -34,7 +34,7 @@ PortSettingsBar::PortSettingsBar(const TQString& title, TQWidget *parent)
    m_box->insertItem(i18n("Always"));
    m_box->insertItem(i18n("Never"));
 
-   connect(m_box,TQT_SIGNAL(activated(int)),this,TQT_SIGNAL(changed()));
+   connect(m_box,TQ_SIGNAL(activated(int)),this,TQ_SIGNAL(changed()));
 }
 
 int PortSettingsBar::selected() const
