@@ -62,7 +62,7 @@ using namespace TDEIO;
 #define SHUT_RDWR 2
 #endif
 
-extern "C" { KDE_EXPORT int kdemain(int argc, char **argv); }
+extern "C" { TDE_EXPORT int kdemain(int argc, char **argv); }
 
 int kdemain( int argc, char **argv )
 {
